package javax.swing.plaf.metal;

import javax.swing.JToolBar;
import javax.swing.JMenuBar;
import javax.swing.UIManager;
import javax.swing.plaf.UIResource;
import java.awt.Graphics;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import javax.swing.plaf.basic.BasicMenuBarUI;

public class MetalMenuBarUI extends BasicMenuBarUI
{
    public MetalMenuBarUI() {
    }
    
    public static ComponentUI createUI(JComponent component) {
        if (component == null) {
            throw new NullPointerException("Must pass in a non-null component");
        }
        return new MetalMenuBarUI();
    }
    
    @Override
    public void installUI(JComponent c) {
        super.installUI(c);
        MetalToolBarUI.register(c);
    }
    
    @Override
    public void uninstallUI(JComponent c) {
        super.uninstallUI(c);
        MetalToolBarUI.unregister(c);
    }
    
    @Override
    public void update(Graphics g, JComponent c) {
        int opaque = c.isOpaque();
        if (g == null) {
            throw new NullPointerException("Graphics must be non-null");
        }
        if (opaque && c.getBackground() instanceof UIResource && UIManager.get("MenuBar.gradient") != null) {
            if (MetalToolBarUI.doesMenuBarBorderToolBar((JMenuBar)c)) {
                JToolBar toolBar = (JToolBar)MetalToolBarUI.findRegisteredComponentOfType(c, JToolBar.class);
                if (toolBar.isOpaque() && toolBar.getBackground() instanceof UIResource) {
                    MetalUtils.drawGradient(c, g, "MenuBar.gradient", 0, 0, c.getWidth(), c.getHeight() + toolBar.getHeight(), true);
                    this.paint(g, c);
                    return;
                }
            }
            MetalUtils.drawGradient(c, g, "MenuBar.gradient", 0, 0, c.getWidth(), c.getHeight(), true);
            this.paint(g, c);
        }
        else {
            super.update(g, c);
        }
        return;
    }
}
